
/* UARTSerialV2
 *
 * Creating some useful functions
 *
Serial MP3 Player A     |  Arduino UNO R3
              RX        |   14
              TX        |   15
              VCC       |   5V
              GND       |   GND
 */
#include <SoftwareSerial.h>
#define ARDUINO_RX 15//should connect to TX of the Serial MP3 Player module
#define ARDUINO_TX 14//connect to RX of the module
SoftwareSerial myMP3(ARDUINO_RX, ARDUINO_TX);

byte sendBuffer[6]; //buffer that will be used to store commands before sending
 
//Manual says the code for this is 7E 03 35 01 EF so load into buffer array
void selectTFCard(){
  sendBuffer[0] = 0x7E;
  sendBuffer[1] = 0x03;
  sendBuffer[2] = 0x35;
  sendBuffer[3] = 0x01;
  sendBuffer[4] = 0xEF;
  sendUARTCommand();
}
 
void playSound(byte songNumber){
  sendBuffer[0] = 0x7E;
  sendBuffer[1] = 0x04;
  sendBuffer[2] = 0x41;
  sendBuffer[3] = 0x00;
  sendBuffer[4] = songNumber;
  sendBuffer[5] = 0xEF;
  sendUARTCommand();
}
//play a sound at a set volume, only seems to apply to root directory files
void playSoundAtVolume(byte volume,byte songNumber){
  sendBuffer[0] = 0x7E;
  sendBuffer[1] = 0x04;
  sendBuffer[2] = 0x31;
  sendBuffer[3] = volume;
  sendBuffer[4] = songNumber;
  sendBuffer[5] = 0xEF;
  sendUARTCommand();
}
//
//set the playback volume 7E 03 31 0F EF = set volume to 0x0F = 15
void setplayVolume(byte volume){
  sendBuffer[0] = 0x7E;
  sendBuffer[1] = 0x03;
  sendBuffer[2] = 0x31;
  sendBuffer[3] = volume;
  sendBuffer[4] = 0xEF;
  sendUARTCommand();
}
 
//stop the current track playing
void stopSound(){
  sendBuffer[0] = 0x7E;
  sendBuffer[1] = 0x02;
  sendBuffer[2] = 0x0E;
  sendBuffer[3] = 0xEF;
  sendUARTCommand();
}
 
void sendUARTCommand(){
  int q;
  for(q=0;q<sendBuffer[1] + 2;q++){
    myMP3.write(sendBuffer[q]);  
  }
  Serial.println("Commands Sent");
  for(q=0;q<sendBuffer[1] + 2;q++){
    Serial.println(sendBuffer[q],HEX);  
  }
  delay(25);//stops odd commands being missed
}
/**********************************************/


//set all of these pins constant
#define rail_1 52 
#define rail_2 50
#define rail_3 48
#define rail_4 46
#define red_fire 44
#define blue_fire 42
#define solenoid 53
#define charge digitalRead(22)
#define fire digitalRead(24)
#define fire_mode digitalRead(26)



void setup() 
{
  // initialize digital pin 13 as an output.
  pinMode(solenoid, OUTPUT);
  pinMode(charge, INPUT);
  pinMode(fire, INPUT);

/********************************************************/
  Serial.begin(9600);
  Serial.println("UARTSerialV2");
  myMP3.begin(9600);
  delay(500);//allow everything to settle down
  //first we need to select the TF Card
  selectTFCard();
/*******************************************************/

pinMode(rail_1, OUTPUT);
pinMode(rail_2, OUTPUT);
pinMode(rail_3, OUTPUT);
pinMode(rail_4, OUTPUT);
pinMode(red_fire, OUTPUT);
pinMode(blue_fire,OUTPUT);
}






/*start loop*/
void loop() 
{ 
  int ready = 1;
  int stop = 0;
  while (charge == HIGH)//wait for charge button to be pressed
  {
    playSoundAtVolume(20, 2);//play sound at volume 20, track 2...drill
    digitalWrite(solenoid, HIGH);
    delay(500);
    digitalWrite(solenoid, LOW);
    delay(125);
    digitalWrite(solenoid, HIGH);
    delay(125);
    digitalWrite(solenoid, LOW);
    delay(250);
    digitalWrite(solenoid, HIGH);
    delay(250);
    digitalWrite(solenoid, LOW);
    
    digitalWrite(rail_1, HIGH); //1st rail LED on
    delay(1250);
    digitalWrite(rail_2, HIGH); //2nd rail LED on
    delay(1250);
    digitalWrite(rail_3, HIGH); //3rd rail LED on
    delay(1250);
    digitalWrite(rail_4, HIGH); //4rd rail LED on

    while (ready)
    {
          while(fire == HIGH) //if fire PB is not pressed then wait
          {
            digitalWrite(rail_4, LOW); //turn off 1st rail LED
            delay(20);
            digitalWrite(rail_3, LOW); //turn off 2nd rail LED
            delay(20);
            digitalWrite(rail_2, LOW); //turn off 3rd rail LED
            delay(20);
            digitalWrite(rail_1, LOW); //turn off 4th rail LED
            delay(20);
            
            playSoundAtVolume(30, 1);//play sound at volume 30, track 1...drill
            delay(200);
            for(int i = 0; i < 30; i++) //do this 30 times
            {
            digitalWrite(red_fire, HIGH); //turn on red fire led
            digitalWrite(blue_fire, HIGH); //turn on blue fire led
            delay(15);
            digitalWrite(solenoid, HIGH); //turn on solenoid
            
            digitalWrite(red_fire, LOW);  //turn off red fire led
            digitalWrite(blue_fire, LOW); //turn off blue fire led
            delay(15);
            digitalWrite(solenoid, LOW); //turn off solenoid
            }
            
            while(fire == HIGH)
            {
             //wait for pushbutton to be released 
            }
            ready = 0; //exit loop
          } 
    }  
  }
